ButtonEvent class abstract

Button Event class

Event of a specific hardware button.

Inheritance
Implemented types

Constructors

ButtonEvent([void updates(ButtonEventBuilder b)?])
factory

Properties

abbrev → String
no setteroverride
button → int
Button identifier.
no setter
dst → int
no setterinherited
dstEnt → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
msgId → int
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
src → int
no setterinherited
srcEnt → int
no setterinherited
sync ↔ int
getter/setter pairinherited
timestamp → DateTime?
no setterinherited
value → int
Value of the button.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ButtonEventBuilder)) → ButtonEvent
Rebuilds the instance.
inherited
toBuilder() → ButtonEventBuilder
Converts the instance to a builder B.
inherited
toJson([bool includeHeader = true]) → Map<String, dynamic>
To JSON object
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

staticId → const int