DevCalibrationStateSerializer class

Device Calibration State serializer class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deserialize(Uint8List data, [int offset = 0]) → DevCalibrationState?
Call to deserialize the all message
override
deserializePayload(DevCalibrationStateBuilder builder, ByteData byteData, Endian endianness, int offset) → int
Call to deserialize only the payload, no header. The Builder is to allow passing the message to build into. returns a int with a serialized size
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(DevCalibrationState? message, [int? syncNumber]) → ByteData
Call to serialize the all message, returns a ByteData with a serialized message
override
serializePayload(DevCalibrationState? message, ByteData byteData, int offset) → int
Call to serialize only the payload, no header, returns a int with a serialized size
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited