FollowPoint class abstract

Follow Point Maneuver class

This maneuver behaves by following a point.

Inheritance
Implemented types

Constructors

FollowPoint([void updates(FollowPointBuilder b)?])
factory

Properties

abbrev → String
no setteroverride
custom → String
Custom settings for maneuver.
no setter
dst → int
no setterinherited
dstEnt → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
lat → double
WGS-84 Latitude of maneuver in the map. Ignored during execution.
no setter
lon → double
WGS-84 Longitude of maneuver in the map. Ignored during execution.
no setter
maxSpeed → double
Use this speed when travelling from afar.
no setter
msgId → int
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speedUnits → SpeedUnitsEnum
Indicates the units used for the maximum speed value.
no setter
src → int
no setterinherited
srcEnt → int
no setterinherited
sync ↔ int
getter/setter pairinherited
target → String
The identifier of the point source to follow (via RemoteSensorInfo or EstimatedState).
no setter
timestamp → DateTime?
no setterinherited
z → double
Use z_units to specify whether z represents depth, altitude or other.
no setter
zUnits → ZUnitsEnum
Units of the z reference.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(FollowPointBuilder)) → FollowPoint
Rebuilds the instance.
inherited
toBuilder() → FollowPointBuilder
Converts the instance to a builder B.
inherited
toJson([bool includeHeader = true]) → Map<String, dynamic>
To JSON object
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

staticId → const int