HistoricTelemetry class abstract

Historic Telemetry class

This message is used to store historic (transmitted afterwards) telemetry information.

Inheritance
Implemented types

Constructors

HistoricTelemetry([void updates(HistoricTelemetryBuilder b)?])
factory

Properties

abbrev → String
no setteroverride
altitude → double
no setter
dst → int
no setterinherited
dstEnt → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
msgId → int
no setteroverride
pitch → int
Pitch encoded as α.(65535/(2.π))
no setter
roll → int
Roll encoded as α.(65535/(2.π))
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speed → int
no setter
src → int
no setterinherited
srcEnt → int
no setterinherited
sync ↔ int
getter/setter pairinherited
timestamp → DateTime?
no setterinherited
yaw → int
Yaw encoded as α.(65535/(2.π))
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(HistoricTelemetryBuilder)) → HistoricTelemetry
Rebuilds the instance.
inherited
toBuilder() → HistoricTelemetryBuilder
Converts the instance to a builder B.
inherited
toJson([bool includeHeader = true]) → Map<String, dynamic>
To JSON object
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

staticId → const int