OpticalBackscatter class abstract

Optical Backscattering Coefficient class

The optical backscattering coefficient refers to all the photons that have been redirected in the backward directions when a photon of light propagates in water and interacts with a "particle" (varying from water molecules to fish).

Inheritance
Implemented types

Constructors

OpticalBackscatter([void updates(OpticalBackscatterBuilder b)?])
factory

Properties

abbrev String
no setteroverride
dst int
no setterinherited
dstEnt int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
msgId int
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
src int
no setterinherited
srcEnt int
no setterinherited
sync int
getter/setter pairinherited
timestamp DateTime?
no setterinherited
value double
Optical Backscattering Coefficient.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(OpticalBackscatterBuilder)) OpticalBackscatter
Rebuilds the instance.
inherited
toBuilder() OpticalBackscatterBuilder
Converts the instance to a builder B.
inherited
toJson([bool includeHeader = true]) Map<String, dynamic>
To JSON object
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

staticId → const int