SessionSubscription class abstract

Session Subscription class

Inheritance
Implemented types

Constructors

SessionSubscription([void updates(SessionSubscriptionBuilder b)?])
factory

Properties

abbrev String
no setteroverride
dst int
no setterinherited
dstEnt int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
messages String
Comma-separated list of messages to subscribe. Example: "EstimatedState,EulerAngles,Temperature"
no setter
msgId int
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessid int
no setter
src int
no setterinherited
srcEnt int
no setterinherited
sync int
getter/setter pairinherited
timestamp DateTime?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SessionSubscriptionBuilder)) SessionSubscription
Rebuilds the instance.
inherited
toBuilder() SessionSubscriptionBuilder
Converts the instance to a builder B.
inherited
toJson([bool includeHeader = true]) Map<String, dynamic>
To JSON object
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

staticId → const int